@@ -2,17 +2,17 @@
 import doctest
 import sys
 if hasattr(doctest, "testfile"):
-    print "=== Test file: README ==="
-    failure,  tests = doctest.testfile('README', optionflags=doctest.ELLIPSIS)
+    print("=== Test file: README ===")
+    failure, tests = doctest.testfile('README', optionflags=doctest.ELLIPSIS)
     if failure:
         sys.exit(1)
 
-    print "=== Test file: test.rst ==="
+    print("=== Test file: test.rst ===")
     failure, tests = doctest.testfile('test/test.rst', optionflags=doctest.ELLIPSIS)
     if failure:
         sys.exit(1)
 
-    print "=== Test IPy module ==="
+    print("=== Test IPy module ===")
     import IPy
     failure, tests = doctest.testmod(IPy)
     if failure:
